@@ -37,7 +37,7 @@ class RoutesMiddleware(object):
         self.use_method_override = use_method_override
         self.path_info = path_info
         log.debug("""Initialized with method overriding = %s, and path info 
-altering = %s""" % (use_method_override, path_info))
+altering = %s""", use_method_override, path_info)
     
     def __call__(self, environ, start_response):
         """Resolves the URL in PATH_INFO, and uses wsgi.routing_args to pass 
@@ -54,12 +54,15 @@ altering = %s""" % (use_method_override, path_info))
                 old_method = environ['REQUEST_METHOD']
                 environ['REQUEST_METHOD'] = req.GET['_method'].upper()
                 log.debug("_method found in QUERY_STRING, altering request"
-                          " method to %s" % environ['REQUEST_METHOD'])
-            elif environ['REQUEST_METHOD'] == 'POST' and '_method' in req.POST:
+                          " method to %s", environ['REQUEST_METHOD'])
+            elif environ['REQUEST_METHOD'] == 'POST' and \
+                 'application/x-www-form-urlencoded' in environ.get('CONTENT_TYPE',
+                                                                    '') \
+                 and'_method' in req.POST:
                 old_method = environ['REQUEST_METHOD']
                 environ['REQUEST_METHOD'] = req.POST['_method'].upper()
                 log.debug("_method found in POST data, altering request "
-                          "method to %s" % environ['REQUEST_METHOD'])
+                          "method to %s", environ['REQUEST_METHOD'])
         
         config.environ = environ
         match = config.mapper_dict
@@ -71,15 +74,15 @@ altering = %s""" % (use_method_override, path_info))
         urlinfo = "%s %s" % (environ['REQUEST_METHOD'], environ['PATH_INFO'])
         if not match:
             match = {}
-            log.debug("No route matched for %s" % urlinfo)
+            log.debug("No route matched for %s", urlinfo)
         else:
-            log.debug("Matched %s" % urlinfo)
-            log.debug("Route path: '%s', defaults: %s" % (route.routepath, 
-                                                          route.defaults))
-            log.debug("Match dict: %s" % match)
+            log.debug("Matched %s", urlinfo)
+            log.debug("Route path: '%s', defaults: %s", route.routepath, 
+                      route.defaults)
+            log.debug("Match dict: %s", match)
         
         for key, val in match.iteritems():
-            if val:
+            if val and isinstance(val, basestring):
                 match[key] = urllib.unquote_plus(val)
         
         environ['wsgiorg.routing_args'] = ((), match)
