@@ -74,9 +74,12 @@ def _subdomain_check(config, kargs):
         return kargs
     
 
-def _url_quote(string):
+def _url_quote(string, encoding):
     """A Unicode handling version of urllib.quote_plus."""
-    return urllib.quote_plus(unicode(string).encode('utf-8'), '/')
+    if encoding:
+        return urllib.quote_plus(unicode(string).encode(encoding), '/')
+    else:
+        return urllib.quote_plus(str(string), '/')
 
 def url_for(*args, **kargs):
     """Generates a URL 
@@ -135,6 +138,7 @@ def url_for(*args, **kargs):
     config = request_config()
     route = None
     static = False
+    encoding = config.mapper.encoding
     url = ''
     if len(args) > 0:
         route = config.mapper._routenames.get(args[0])
@@ -158,8 +162,8 @@ def url_for(*args, **kargs):
                 query_args = []
                 for key, val in kargs.iteritems():
                     query_args.append("%s=%s" % (
-                        urllib.quote_plus(unicode(key).encode('utf-8')),
-                        urllib.quote_plus(unicode(val).encode('utf-8'))))
+                        urllib.quote_plus(unicode(key).encode(encoding)),
+                        urllib.quote_plus(unicode(val).encode(encoding))))
                 url += '&'.join(query_args)
     if not static:
         if route:
@@ -179,7 +183,7 @@ def url_for(*args, **kargs):
         protocol = newargs.pop('_protocol', None) or protocol
         url = config.mapper.generate(**newargs)
     if anchor:
-        url += '#' + _url_quote(anchor)
+        url += '#' + _url_quote(anchor, encoding)
     if host or protocol or qualified:
         if not host and not qualified:
             # Ensure we don't use a specific port, as changing the protocol
@@ -191,6 +195,11 @@ def url_for(*args, **kargs):
             protocol = config.protocol
         if url is not None:
             url = protocol + '://' + host + url
+    
+    if not isinstance(url, str) and url is not None:
+        raise Exception("url_for can only return a string or None, got "
+                        " unicode instead: %s" % url)
+    
     return url
 
 def redirect_to(*args, **kargs):
